.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mar 07 apr 2009 13:10:37 CEST
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

=====================================
 Le Regole Internazionali del Carrom
=====================================

Traduzione *libera* dall'originale in inglese delle `Official Laws
of CARROM`__ pubblicate della `Federazione Internazionale Carrom`__.

__ http://www.carrom.org/icf/?page=1&subcat=20
__ http://www.carrom.org/

.. warning:: Queste **non sono** le `Regole Ufficiali`__ della
             `Federazione Italiana Carrom`__, benché nella sostanza
             siano del tutto equivalenti: la differenze principali sono
             nella numerazione degli articoli e in piccole differenze
             nella formattazione del testo.

__ http://www.carromitaly.com/regoleFIC.html
__ http://www.carromitaly.com/

.. contents:: Sommario
   :local:

Glossario
=========

Nel contesto di questo Regolamento, i seguenti termini devono
essere così interpretati:

.. glossary::

   Regole
     si intendono le “Regole del Carrom”.

   Tiro
     significa colpire una pedina con lo Striker, direttamente
     o indirettamente.

   Tiro corretto
     (o “proprio”) significa in accordo con le Regole.

   Tiro scorretto
     (o “improprio”) è da intendere contrario alle Regole.

   C/B
     indica il Carrom Board, cioè il Tavolo da Gioco.

   C/M
     è l'abbreviazione di Carrommen, le Pedine, sia al
     plurale che al singolare.

   Board
     si intende una singola giocata, dalla spaccata iniziale
     alla conclusione.

   Partita
     (o “game”) si indica una serie di massimo 8 board fino
     ad arrivare ai 25 punti.

   Incontro
     (o “match”) è da intendersi come una sfida al miglior
     risultato su tre game

   Spaccata
     (o “break”) indica il primo tiro di un board.

   Finire
     significa imbucare tutte le proprie pedine sul tavolo.

   Giocatore
     s'intende un Giocatore di Carrom.

   Piazzare
     indica il posizionamento, da parte di chi è autorizzato dalle
     Regole a farlo, delle pedine di penalità o pegno all'interno del
     Cerchio Esterno, in posizione piana. La Regina e/o le C/M che
     sono uscite dal tavolo devono sempre essere messe dall'Arbitro, a
     coprire il Cerchio Centrale.

   Imbucare
     significa spingere una pedina o la Regina in una delle buche, sia
     con un tiro corretto che con uno improprio.

   Spingere
     indica quando lo Striker viene mosso con un movimento brusco del
     gomito piuttosto che colpito con la punta del dito.

   Regina
     è la pedina rossa.

   Pegno
     è quando lo Striker finisce in buca, insieme a altre pedine o
     meno.

   Penalità
     indica una punizione per aver commesso un fallo violando una
     delle Regole.

   Conferma
     significa imbucare una propria pedina, nello stesso tiro o in
     quello immediatamente successivo, da parte di un giocatore che
     abbia messa in buca la Regina.

   Shot
     significa un :term:`pair` o un :term:`cannon`.

   Pair
     indica una coppia di pedine posizionate dentro il Cerchio
     Esterno, distanziate tra loro ma allineate verso una delle buche.

   Cannon
     indica una coppia di pedine a contatto tra di loro, posizionate
     nel Cerchio Esterno e allineate verso una delle buche.

   Thumbing
     indica un tiro fatto utilizzando il pollice.

   Turno
     significa avere il diritto di tirare.

   Giuria
     è la persona o gruppo di persone ufficialmente incaricate di
     dirimere eventuali controversie in un torneo.

   Arbitro
     è la persona ufficialmente incaricata di supervedere e/o
     controllare un incontro o un torneo.

   Avversario nei Singoli
     è chi in quel determinato momento non ha il turno di gioco.

   Avversario nei Doppi
     è sia il giocatore seduto alla sinistra che quella alla destra di
     chi in quel momento ha il turno di gioco.

   Mano
     è da intendere la porzione che va dalle dita fino al polso della
     mano usata per giocare.

   Dito
     indica la porzione che comprende le prime due falangi del dito
     usato per giocare.

   Linee immaginarie
     si intendono i prolungamenti delle linee diagonali con le frecce
     che passano in mezzo ai Cerchi di Base.

   Slam bianco
     lo effettua chi riesce a imbucare tutte le pedine bianche e la
     Regina, nel rispetto delle Regole, al suo primo turno di
     gioco. Viene anche chiamato “Break to Finish”.

   Slam nero
     si intende il realizzare tutte le rimanenti pedine nere, inclusa
     o meno la Regina, al primo turno di gioco, rispettando ovviamente
     le Regole.

.. note:: Il singolare comprende il plurale, e il maschile comprende
          il femminile.

Posizione di gioco
==================

1. Nei Singoli, i giocatori si siedono uno di fronte all'altro.

2. Nei Doppi, i giocatori di ciascuna coppia giocano uno di fronte
   all'altro, occupando in tal modo tutti e quattro i lati.

3. La posizione assunta da un giocatore prima del suo turno di gioco
   può essere cambiata in qualunque momento, a patto che per tutta la
   durata del suo turno la posizione della sedia o dello sgabello su
   cui è seduto rimanga immutata.

4.

  (a) Durante la partita, nessuna parte del corpo dei giocatori, ad
      eccezione del braccio utilizzato per il tiro, può toccare il
      Tavolo o il sostegno su cui è appoggiato.

  (b) Ciascun giocatore, durante il proprio turno di gioco, dovrà
      comunque assicurarsi che gli eventuali indumenti, anelli,
      braccialetti e orologi non tocchino la superficie di gioco.

5. È permesso l'utilizzo di qualsiasi materiale per alzare e/o
   aggiustare l'altezza della sedia, ma solo dopo la conclusione della
   partita.

6. Nessuna parte del corpo del giocatore, eccettuata la mano con cui
   tira, può superare le linee immaginarie diagonali.

Come si effettua il tiro
========================

7. Lo Striker deve essere colpito, non spinto.

8. Il tiro deve essere effettuato con un dito, con o senza il supporto
   delle altre dita.

9. Per giocare si può utilizzare una qualsiasi delle due mani.

10. Mentre si sta per tirare, la mano può toccare la superficie di
    gioco.

11.

   (a) Il gomito della mano utilizzata per giocare non deve toccare la
       superficie di gioco e non può oltrepassare le linee immaginarie.

   (b) La mano utilizzata, tuttavia, può superare le linee immaginarie.

12.

   (a) Mentre si effettua il tiro, non è permesso ancorarsi in alcun
       modo alla propria sedia, né tantomeno al sostegno del Tavolo,
       oppure tenere le gambe appoggiate all'eventuale rinforzo del
       sostegno.

   (b) L'avversario tuttavia potrà tenere appoggiate le mani sul
       proprio corpo o sulle gambe, o riposarsi appoggiandosi agli
       eventuali braccioli o schienale della sedia.

Lancio della moneta
===================

13.

   (a) All'inizio di ogni incontro, l'Arbitro dovrà stabilire chi
       effettuerà la prima spaccata. Potrà farlo lanciando una moneta
       oppure estraendo una pedina a caso. Il giocatore estratto potrà
       decidere su quale lato giocare oppure partire per primo. Dovesse
       scegliere la posizione di gioco, dovrà comunicare la sua
       decisione all'Arbitro, che provvederà a far sedere per primo
       l'altro giocatore.

   (b) Nei Doppi, la coppia estratta avrà la stessa possibilità di
       scelta come sopra.

   (c) Se, invece, il giocatore estratto preferisse la spaccata, la
       scelta del posto di gioco spetta all'altro giocatore e quindi
       l'Arbitro farà sedere per primo il giocatore estratto.

   (d) Una volta che i giocatori non estratti sono seduti, non possono
       scambiarsi ulteriormente di posto. Questo medesimo ordine dovrà
       essere mantenuto per tutta la durata dell'incontro.

Partita di riscaldamento
========================

Possono essere effettuate due partite di riscaldamento, una per ogni
giocatore o coppia. Tali partire andranno giocate dopo che è stata
fatta l'estrazione e prima di cominciare l'incontro vero e proprio.

Spaccata
========

14.

   (a) Prima della spaccata, le pedine devono essere disposte in
       posizione piana in modo tale che la Regina occupi il Cerchio
       Centrale e il resto delle pedine intorno ad essa, una prima
       cerchia alternando una pedina bianca a una nera. Nella seconda,
       le pedine bianche formeranno una specie di “Y” con al centro la
       Regina, mentre lo spazio rimanente va riempito alternativamente
       di pedine bianche e nere. Una volta sistemate, tutte le pedine
       devono toccarsi l'una con l'altra a formare un cerchio compatto
       all'interno del Cerchio Esterno. Il giocatore può utilizzare le
       dita o lo Striker per far combaciare le pedine.

   (b) Questa disposizione delle pedine prima della spaccata deve
       essere effettuata con la minor perdita di tempo possibile alla
       fine di ciascuna partita.

15. La spaccata va effettuata dal giocatore che ha scelto di tirare per
    primo.

16. Il giocatore che esegue la spaccata avrà le pedine bianche, il suo
    avversario quelle nere, per tutta la durata di una singola
    partita. La Regina è in comune.

17. La spaccata è da considersi effettuata se lo Striker tocca anche
    solo leggermente una qualsiasi pedina.

18.

   (a) La spaccata non è da considerare effettuata se lo Striker non
       tocca nessuna delle pedine nella sua corsa. In tal caso, il
       giocatore ha a disposizione al massimo altri due tentativi.

   (b) Se dopo il numero consentito di tentativi nessuna pedina fosse
       ancora stata toccata, il giocatore perde il diritto di spaccare,
       che passa all'avversario, il quale conserva le pedine nere, ma
       non gli è permesso di risistemare le pedine sul tavolo. Se anche
       l'avversario non riuscisse a effettuarla, la spaccata torna al
       primo giocatore, e così via, fino a ché non riesce.

   (c) Se un giocatore, nel tentativo di spaccare, gioca un tiro
       improprio o imbuca il suo Striker senza aver toccato alcuna
       pedina, egli perde il turno, senza sottostare a nessuna
       penalità.

19. La spaccata deve essere effettuata solo dopo che l'Arbitro abbia
    dato il “Via”. Da quel momento il gioco è considerato valido e
    il tiro deve essere effettuato entro 15 secondi dall'annuncio.

20. Se la spaccata viene effettuata prima che l'Arbitro abbia dato il
    “Via”, tutte le pedine e la Regina eventualmente imbucate vanno
    riposizionate sul Tavolo. Il giocatore paga una pedina di penalità
    e perde il turno di gioco.

Turno di gioco
==============

21. Fintantoché un giocatore imbuca le sue pedine e/o la Regina in
    accordo con le Regole, egli conserva il turno di gioco.  Altrimenti
    questo passa al suo avversario.

22. Turnazione:

    (a) Singoli

        i. Nella prima partita, il giocatore che ha scelto di partire per
           primo ha le pedine bianche. Il turno di spaccata passa
           alternativamente all'uno e all'altro giocatore durante
           l'incontro.

        ii. Nella seconda partita, esegue la spaccata per primo chi non
            l'ha effettuata nella prima partita.

        iii. Nella terza partita, la prima spaccata viene effettuata di
             nuovo dal primo giocatore.

    (b) Nei Doppi, il turno passa al giocatore che siede alla destra di
        chi l'ha effettuata la volta precedente.

23. Un giocatore deve effettuare il suo tiro entro 15 secondi dal
    momento che lo Striker dell'avversario si è fermato ed è stato
    rimosso dal Tavolo, oppure da quando sono state posizionate le
    pedine di penalità.

24. Se un giocatore effettua il tiro quando non è il turno senza che
    l'Arbitro abbia modo di fermarlo, il giocatore in questione perde
    la partita delle pedine e Regina ancora presenti sul Tavolo. Se
    l'accaduto non viene notato da alcuno prima che il giocatore
    successivo abbia tirato, viene considerato valido e la partita
    prosegue normalmente.

Calcolo dei punti
=================

25.

   (a) Il giocatore che per primo imbuca tutte le proprie pedine, vince
       la partita.

   (b) I punti sono calcolati come segue:

       i. Regina: 3 punti fino al raggiungimento dei 21 punti inclusi.

       ii. Pedine: 1 punto per ogni pedina.

26.

   (a) Il numero delle pedine avversarie ancora sul Tavolo darà il
       punteggio ottenuto da quel giocatore in quella partita.

   (b) Al giocatore vengono accreditati i punti della Regina solo in
       caso egli vinca la partita.

   (c) Il giocatore che perde la partita non otterrà alcun punteggio
       dalla Regina, anche se l'avesse regolarmente imbucata e
       confermata.

27. Il giocatore perde la possibilità di avvantaggiarsi dei 3 punti
    della Regina quando raggiunge i 22 punti.

28. Il punteggio massimo realizzabile in una partita è 12.  Eventuali
    pegni o penalità dell'avversario devono essere ignorati.

29.

   (a) Un incontro termina ai 25 punti oppure dopo otto partite.  Il
       giocatore che raggiunge per primo i 25 punti o che è in
       vantaggio alla conclusione dell'ottavo board è il vincitore
       dell'incontro.

   (b) Fino agli ottavi di finale inclusi, ogni incontro viene
       disputato sulla base di otto board. Se al termine dell'ottavo
       board si fosse in condizione di parità, si giocherà un ulteriore
       partita per stabilire il vincitore. Prima di giocare, si dovrà
       stabilire, tirando a sorte, il giocatore con diritto di spaccare
       per primo.

30. Tutti gli incontri saranno decisi al meglio di tre partite.

Cambio campo
============

31. Nei Singoli, i giocatori si devono scambiare il posto alla fine di
    ogni game.

32. Nei Doppi, il cambio viene effettuato spostando ogni giocatore di
    un posto alla sua destra, alla fine di ogni incontro.

33.

   (a) Fino agli ottavi di finale inclusi, il cambio campo deve essere
       effettuato dopo la quarta partita o appena uno dei
       giocatori/delle coppie raggiunge i 13 punti.

   (b) Dai quarti di finale in avanti il cambio campo va effettuato nel
       momento in cui uno dei giocatori/delle coppie raggiunge i 13
       punti.

   (c) Il cambio di campo, se passa inosservato sia dall'Arbitro sia
       dai giocatori, dovrà essere fatto nel momento in cui viene
       notata la mancanza, dopo la conclusione della partita in corso.

34. I giocatori non devono impiegare più di due minuti per scambiarsi
    il posto.

Falli
=====

35. In generale, qualsiasi violazione delle Regole o qualsiasi cosa
    fatta in contrasto con quanto specificato o comunque inteso dalle
    presenti Regole, dovrà essere classificato in:

    (a) Fallo tecnico
    (b) Fallo

Fallo tecnico
-------------

36.

   (a) Qualsiasi violazione delle Regole commessa da un giocatore prima
       del suo primo tiro al suo turno di gioco verrà detta “fallo
       tecnico”. Tale violazione comporta il riposizionamento, da parte
       dell'avversario, di una delle pedine imbucate dal giocatore, che
       poi potrà proseguire il suo gioco.

   (b) Qualsiasi violazione delle Regole commessa dall'avversario (cioè
       dal giocatore che non ha in quel momento il turno di gioco),
       verrà detta “fallo tecnico”, e subirà la stessa penalità imposta
       nel punto precedente.

Fallo
-----

37.

  (a) Qualunque violazione delle Regole commessa da un giocatore
      durante o dopo il suo primo tiro, ad ogni turno di gioco, viene
      chiamata “fallo”. Questo comporta il riposizionamento, da parte
      dell'avversario, di una delle pedine imbucate dal giocatore e la
      perdita per quest'ultimo del turno di gioco.

  (b) Se il fallo viene commesso imbucando una pedina o la Regina,
      tutte le pedine imbucate, compresa l'eventuale Regina, verranno
      riposizionate sul tavolo e il turno di gioco passa la giocatore
      successivo.

Pedine fuori dal tavolo
=======================

38.

   (a) Qualora una pedina, o la Regina, dovesse uscire dalla superficie
       di gioco dovrà essere rimesse dall'Arbitro a coprire il Cerchio
       Centrale o, se lo spazio non lo permette, a occuparne la maggior
       parte possibile.

   (b) Dovessero uscire contemporaneamente una pedina insieme alla
       Regina, la precedenza va a quest'ultima che dovrà pertanto
       essere posizionata per prima, mentre l'altra pedina andrà messa
       a contatto con la Regina, sul lato opposto al giocatore che ha
       il turno di gioco.

   (c) Se invece nello stesso tiro escono una pedina bianca e una nera,
       la precedenza va alla pedina del giocatore che ha effettuato il
       tiro, l'altra posizionata a contatto nella stessa maniera
       descritta nel punto precedente.

   (d) Quando escono dal Tavolo più di due pedine, le prime due devono
       essere posizionate seguendo le direttive esposte nei punti
       precedenti, le altre disposte in modo da toccarle, per quanto
       possibile.

39.

   (a) Se una pedina, o la Regina, dovesse uscire dalla superficie di
       gioco e ricadervi, quella pedina o la Regina dovrà essere
       riposizionata dall'Arbitro sul Cerchio Centrale secondo le
       Regole. L'Arbitro potrà, a sua discrezione, ripristinare la
       posizione delle altre pedine eventualmente coinvolte.

   (b) Tuttavia, se la pedina, o la Regina, dovesse rientrare sul
       Tavolo dopo aver urtato contro il sostegno della lampada, o
       contro la lampada stessa, questo verrà considerato come un suo
       movimento naturale, e le pedine eventualmente coinvolte dovranno
       rimanere dove sono.

Pedine che rotolano e si sovrappongono
======================================

40. Se una pedina o la Regina rimane verticale sul suo bordo, dovrà
    essere lasciata in quella posizione.

41. Se due pedine e/o la Regina si sovrappongono, dovranno essere
    lasciate come stanno.

42.

   (a) Qualora lo Striker si fermasse su una pedina o sulla Regina,
       dovrà essere rimosso dall'Arbitro senza disturbare la posizione
       della pedina. Se la pedina dovesse muoversi nell'intento,
       l'Arbitro dovrà ripristinarne, per quanto possibile, la
       posizione originale.

   (b) Se questo succede sull'orlo di una buca e nel rimuovere lo
       Striker la pedina o la Regina dovessere perdere il loro centro
       di gravità e cadere nella buca, verrà considerata come
       propriamente imbucata.

43.

   (a) Se una pedina o la Regina si ferma sopra lo Striker, l'Arbitro
       dovrà rimuoverlo alzando la pedina e poi riappoggiandola, per
       quanto possibile, come se lo Striker non fosse stato là.

   (b) Se però questo succedesse sull'orlo di una buca e rimuovendo la
       pedina o la Regina lo Striker, perdendo il proprio centro di
       gravità dovesse cadervi, verrà considerato come imbucato: il
       giocatore dovrà pagare una penalità come previsto dalle Regole.

44. Se una pedina, in precedenza ferma sull'orlo di una buca, vi cade
    per qualsiasi ragione, verrà considerata propriamente imbucata.

Pegni e penalità
================

45.

   (a) Se, sia con un tiro corretto che con uno improprio, un giocatore
       imbuca il proprio Striker da solo, egli perderà il turno di
       gioco e dovrà pagare una pedina di penalità, che dovrà essere
       posizionata dall'avversario. Questa pedina viene chiamata
       “Pegno”.

   (b) Qualora il giocatore in questione non avesse ancora imbucato
       nessuna delle sue pedine, la penalità rimarrà in sospeso finché
       non si renda disponibile una pedina.

46. Se un giocatore imbuca il suo Striker insieme a una o più delle
    proprie pedine, queste dovranno essere riposizionate sul Tavolo,
    più una di penalità e il giocatore mantiene il turno di gioco.

47. Quando un giocatore imbuca il proprio Striker insieme a pedine
    dell'avversario, queste verranno considerate come fatte. Verrà
    applicata la pedina di pegno prevista e il giocatore perde il turno
    di gioco.

48. Qualora lo Striker finisse in buca insieme a pedine sia proprie che
    avversarie, dovranno essere riposizionate, a cura dell'avversario,
    solo quelle del giocatore, più una di penalità, quindi il giocatore
    mantiene il turno di gioco.

49. Se un giocatore imbuca delle pedine dell'avversario con un tiro
    improprio, verranno considerate regolarmente realizzate, il
    giocatore subirà una pedina di penalità posizionata dall'avversario
    e perderà il turno di gioco.

50.

   (a) Quando un giocatore imbuca le sue pedine con un tiro improprio,
       quelle stesse pedine più una di penalità dovranno essere rimesse
       in gioco dall'avversario, al quale passerà anche il turno di
       gioco.

   (b) Qualora il giocatore imbucasse il suo Striker insieme a proprie
       pedine con un tiro improprio, quelle stesse pedine più una di
       penalità dovranno essere rimesse in gioco dall'avversario, al
       quale passerà anche il turno di gioco.

51.

   (a) Il pegno o la penalità dovranno essere rimesse in gioco non
       appena si rendano disponibili, dopo la conclusione del tiro ma
       eventualmente nel turno di gioco dello stesso giocatore.

   (b)

     i. Nei Doppi la penalità va rimessa in gioco dal giocatore che
        siede alla destra di chi a il turno di gioco al momento che la
        pedina si rende disponibile.

     ii. Se però, durante il turno di un giocatore, questo imbucasse
         delle pedine dell'avversario, magari insieme alle proprie,
         rendendo così disponibile la penalità, dovrà essere il
         giocatore stesso a estrarla e riposizionarla.

52.

   (a) Se la pedina di penalità è disponibile ma non c'è spazio a
       sufficienza per piazzarla, è consentito a chi deve farlo di
       posticipare finché si liberi lo spazio necessario.

   (b) Nei Doppi, qualora un giocatore decida di posticipare il
       piazzamento passando di fatto la responsabilità al proprio
       partner, solo quest'ultimo avrà diritto a farlo.

53. Se lo spazio necessario al posizionamento della penalità fosse
    disponibile ma il giocatore al quale spetta farlo non volesse
    rischiare un fallo, egli dovrà rinunciarvi e la penalità verrà
    annullata.

54. Quando si renda disponibile lo spazio necessario al posizionamento
    della penalità durante il turno di un giocatore autorizzato a
    farlo, la pedina andrà piazzata immediatamente.

55.

  (a) Se il giocatore che piazza la penalità si dovesse sbagliare
      ponendo sul Tavolo delle proprie pedine anziché quelle del
      giocatore che ha commesso il fallo, dovrà essere rettificato, se
      questo viene fatto notare dall'Arbitro o da uno dei
      giocatori. Avendo commesso fallo, dovrà subire la penalità
      prevista dalle Regole.

  (b) Se la cosa non viene notata dall'Arbitro o da uno degli
      avversari prima che sia effettuato il tiro successivo, le C/M
      riposizionate verranno considerate valide e regolari.

56. Se un giocatore è in debito di più di una pedina di penalità, le
    pedine disponibili devono essere rimesse immediatamente in gioco,
    le altre non appena vengano imbucate.

57.

  (a) Il posizionamento va considerato concluso non appena il
      giocatore stacca il dito dalla pedina, ammesso che questa si
      trovi dentro il Cerchio Esterno.

  (b) Non è consentito inoltre trattenere in mano altre pedine o lo
      Striker mentre si posiziona la penalità.

58. Quando un giocatore pone o sposta la penalità fuori dal Cerchio
    Esterno, gli verrà chiesto di metterla al suo interno.  Viene
    dichiarato fallo, con le conseguenze previste dalle Regole.

59. Nel piazzare la pedina di penalità, il giocatore non deve muovere
    nessun'altra pedina o la Regina. Il posizionamento della pedina
    non deve essere disturbare altre pedine o la Regina. Se questo
    accadesse, l'Arbitro dovrà ripristinare per quanto possibile le
    posizioni originali e dichiarare fallo nei confronti del
    giocatore, con le conseguenze previste dalle Regole.

60. Un giocatore può condonare una penalità all'avversario, a patto
    che si tratti della sua totalità e non solo di una parte.  Questa
    decisione va comunicata all'Arbitro entro 15 secondi, scaduti i
    quali il diritto a piazzare la penalità decade.

61. Il limite di tempo entro il quale posizionare la penalità, dopo
    l'annuncio fatto dall'Arbitro, è di 15 secondi.

62.

  (a) Le penalità non potranno essere posizionate direttamente a
      contatto con pedine già presenti.

  (b) Le pedine di pegno o penalità, quando vengono posizionate, non
      devono coprire il Cerchio Centrale nemmeno parzialmente.  Se
      questo dovesse accadere, si chiederà al giocatore di aggiustarne
      la posizione e verrà dichiarato fallo nei suoi confronti.

63. Nei Doppi, un giocatore non deve estrarre le pedine di penalità
    quando a sistemarle deve essere il suo partner. Nel caso in cui
    quest'ultimo non trovasse le pedine nelle buche vicine a lui, le
    dovrà chiedere all'Arbitro, specificandone il numero e il colore.

64. Se nel corso della partita un giocatore si alzasse per qualsiasi
    ragione dal suo posto, sia durante il suo turno che quello
    dell'avversario, perderà il game di quante sono le sue pedine, più
    l'eventuale Regina, ancora sul Tavolo. Se il punteggio
    dell'avversario è di 22 punti o più, la Regina non deve essere
    conteggiata.

Regina
======

65. Un giocatore ha diritto a imbucare la Regina e quindi a confermarla
    quando almeno una delle sue pedine sia già stata imbucata.

66. La Regina deve essere piazzata dall'Arbirtro esclusivamente sul
    Cerchio Centrale. Se nel piazzarla si dovesse formare un shot non
    potrà essere alterato.

67. Se il Cerchio Centrale fosse parzialmente o completamente coperto
    da altre pedine, la Regina dovrà essere piazzata in modo da
    occuparne quanto più possibile la porzione disponibile, oppure in
    una posizione adiacente al Cerchio Centrale in maniera tale che non
    sia facilmente realizzabile dal giocatore di turno. In tali casi,
    la decisione definitiva spetta all'Arbitro.

68.

   (a) Quando la Regina viene imbucata prima di aver realizzato almeno
       un'altra pedina, la Regina va riposizionata al centro e il
       giocatore perde il turno.

   (b) Se un giocatore imbuca la Regina quando è in debito di una
       penalità, la Regina va rimessa al centro e il giocatore perde il
       turno.

   (c) Se, durante la spaccata o in un tiro successivo quando tutte le
       pedine del giocatore sono ancora sul Tavolo, viene imbucata la
       Regina insieme allo Striker, la Regina va rimessa al centro, il
       giocatore paga una pedina di penalità e perde il turno.

69. Se la Regina viene imbucata ma non viene confermata al tiro
    successivo, deve essere rimessa in gioco. Se però questo non viene
    notato né dall'Arbitro né dall'avversario prima che sia effettuato
    il tiro successivo, la Regina viene considerata regolarmente
    confermata.

70. Quando la Regina viene imbucata contemporaneamente a una pedina del
    giocatore, viene considerata confermata.

    (a) Se però questo succede durante la spaccata, o in un tiro
        successivo quando tutte le pedine del giocatore sono ancora in
        gioco, la Regina deve essere confermata. Tuttavia se più di una
        pedina fosse stata imbucata insieme alla Regina, questa è da
        considerare confermata.

71. Per i successivi casi, se la situazione si verifica in seguito ad
    un tiro improprio, il giocatore subisce una ulteriore pedina di
    penalità, oltre a quelle indicate e perde in ogni caso il turno di
    gioco.

    (a) Se la Regina, una pedina e lo Striker finissero in buca
        contemporaneamente con un tiro corretto, sia la Regina che la
        pedina, più una di penalità, dovranno essere rimesse in gioco e
        il giocatore conserva il turno.

    (b) Qualora un giocatore imbucasse la Regina insieme allo Striker
        con un tiro corretto, la Regina e una sua pedina vanno rimesse
        in gioco dall'Arbitro e il giocatore mantiene il turno.

    (c) Se nel tentare di confermare la Regina venisse imbucato lo
        Striker da solo, la Regina va rimessa in gioco e il giocatore
        dovrà pagare una pedina di pegno e poi perde il turno.

    (d) Se tentando di confermare la Regina il giocatore imbuca lo
        Striker insieme a una delle sue pedine, quest'ultima più una di
        penalità dovranno essere rimesse in gioco e il giocatore
        conserverà il turno. Nel caso in cui non riuscisse a confermarla
        nel successivo tiro, la Regina verrà rimessa al centro del
        Tavolo.

72. Nei seguenti casi, il giocatore che effettua il tiro vince la
    partita, aggiudicandosi i soli punti della Regina, che vale 3 fino
    al raggiungimento dei 21 punti, superati i quali vale un solo
    punto. Se però si verificassero in seguito a un tiro improprio, è
    l'avversario ad aggiudicarsi la partita con il medesimo punteggio:
    in tal caso l'avversario potrà avvalersi del diritto di farsi
    conteggiare anche la pedina di pegno del giocatore che ha commesso
    il fallo, facendone esplicita richiesta.

    (a) Confermando la Regina, vengono imbucate contemporaneamente le
        ultime pedine di entrambi i giocatori

    (b) Nello stesso tiro vanno in buca la Regina l'ultima pedina del
        giocatore e anche l'ultima dell'avversario.

73. Nei casi che seguono invece è sempre l'avversario ad aggiudicarsi
    la partita del numero di pedine ancora sul tavolo più la Regina, se
    presente; egli potrà o meno esigere il pagamento della pedina di
    pegno dovuta in caso di tiro irregolare, come nel punto
    precedente. La Regina viene conteggiata normalmente fino al
    raggiungimento dei 21 punti (del giocatore che se l'aggiudica),
    superati i quali non deve essere inclusa nel punteggio, salvo
    quando ci sia la sola Regina sul tavolo, nel qual caso vale un
    singolo punto come una normale pedina.

    (a) Tentando di confermare la Regina, si dovesse imbucare l'ultima
        pedina dell'avversario

    (b) Quando un giocatore imbuca la sua e/o l'ultima pedina
        dell'avversario mentre la Regina è ancora sul Tavolo.

    (c) Se un giocatore imbuca la sua ultima pedina insieme all'ultima
        dell'avversario, perde la partita per un punto se la Regina è
        stata confermata da lui, oppure di tre punti fosse stato
        l'avversario ad aggiudicarsela.

74. Se la Regina finisse per posizionarsi sull'orlo di una buca e in
    seguito, per qualsiasi ragione, vi cadesse dentro, va considerata
    regolarmente imbucata.

75. Un giocatore non può sistemare la penalità per formare un shot con
    la Regina. Quando accadesse, l'Arbitro dovrà richiamare il
    giocatore a spostare la pedina, dichiarandogli fallo.

Generale
========

76. Il tiro può essere effettuato solo utilizzando uno Striker, che
    dovrà essere presentato dal giocatore e certificato dall'Arbitro
    prima dell'inizio dei giochi.

77. Se mentre effettua il tiro lo Striker del giocatore dovesse uscire
    dal tavolo imbucando al contempo proprie pedine e/o la Regina, il
    giocatore conserverà il turno.

78. È consentito cambiare il proprio Striker con un altro, debitamente
    controllato e approvato dalla Giuria, solo alla conclusione della
    partita. Tuttavia, se durante il gioco lo Striker dovesse rompersi,
    è permessa la sua sostituzione al termine del tiro corrente.

79.

   (a) Una volta posizionato, la posizione del tavolo deve rimanere
       inalterata per tutta la durata dell'incontro.

   (b) La sola e unica autorità che può cambiarne la posizione, dopo un
       attento esame dietro appello di uno dei giocatori, è l'Arbitro.

80. Il Tavolo o il supporto su cui è appoggiato destinato a un
    particolare incontro non potrà essere sostituito se non al termine
    di una partita. L'Arbitro è l'unica autorità che può prendere
    decisioni sulle condizioni del Tavolo o delle sedie.

81. Qualsiasi pedina rovinata di cui sia stata accettata la
    sostituzione, sarà rimpiazzata dall'Arbitro mantenendone la stessa
    posizione per quanto possibile.

82.

   (a) Il conteggio del tempo viene fermato quando uno dei giocatori si
       appella all'Arbitro. Il gioco non può continuare fino a che
       l'Arbitro abbia dato il “Via”.

   (b) Chi non osserva questa regola perde immediatamente la partita di
       tanti punti quante sono le sue pedine ancora sul Tavolo, più
       quelli eventuali della Regina, secondo le Regole, se fosse
       ancora in gioco.

83.

   (a) La polvere deve essere distribuita uniformemente dal giocatore
       di turno subito prima della spaccata. La quantità di polvere non
       dovrà essere né eccessiva né troppo scarsa.

   (b)

     i. La polvere non può essere più aggiunta o rimossa una volta che
        l'Arbitro abbia dato il “Via”.

     ii. Non è permesso alcun tentativo volontario di rimuovere o
         spostare la polvere dalla superficie di gioco.

     iii. Non è permesso tentare di rimuoverla nemmeno soffiandovi
          sopra, o in qualsiasi altra maniera.

   (c) Tuttavia, il giocatore di turno può, utilizzando il suo Striker,
       rimuovere e/o sistemare l'eccessiva polvere che fosse presente
       lungo le sue Linee di Base o attorno ai propri Cerchi di Base.

   (d) L'Arbitro ha il diritto di controllare l'uniformità della
       distribuzione della polvere sulla superficie del Tavolo.

   (e) Si deve richiedere all'Arbitro la rimozione di cenere, insetti e
       quant'altro fosse presente sul Tavolo durante la partita.

84. Un tiro è da considerare concluso solo quando sia lo Striker sia le
    pedine, Regina compresa, da esso movimentate si fermano.  Lo
    Striker deve essere rimosso immediatamente dopo dal
    giocatore. L'Arbitro può prestare assistenza, se richiesto.

85.

  (a) Finché il giocatore continua a imbucare le sue pedine e/o la
      Regina, il conteggio del tempo comincia non appena il tiro è
      completato.

  (b) Quando però il giocatore non riesce a imbucare alcunché, il
      conteggio del tempo deve partire dal momento in cui rimuove il
      suo Striker dal Tavolo.

86.

  (a) When a player pockets the C/M of his opponent knowingly or
      unknowingly, the Umpire shall stop the player from playing
      further.

  (b) If unnoticed by the Umpire or by the opponent, the C/M pocketed
      shall be considered to have been properly pocketed.  The turn of
      the player shall be lost as and when noticed.

87.

  (a) Un giocatore non può urtare, tamburellare o comunque disturbare
      il Tavolo di gioco, sia di proposito che inavvertitamente. Se
      questo accadesse deve essere dichiarato fallo nei confronti del
      giocatore.

  (b) Tuttavia se l'intervento del giocatore è tale che la posizione
      originale delle pedine non possa essere ripristinata, egli perde
      la partita di tanti punti quante sono le sue pedine ancora sul
      Tavolo, più quelli eventuali della Regina, secondo quanto
      prescritto dalle Regole.

88.

  (a) Un tiro è da considerare effettuato non appena lo Striker non è
      più a contatto delle Linee di Base o dei Cerchi di Base,
      indipendentemente dal fatto di aver toccato o meno delle pedine.

  (b) Se invece lo Striker non esce dalle Linee di Base o dai Cerchi
      di Base e non tocca nessuna pedina, il tiro non va considerato
      come effettuato.

89. Un giocatore può chiedere all'Arbitro il punteggio dell'incontro
    solo durante il suo turno di gioco.

90. Un giocatore non deve distrarre l'avversario in nessuna maniera.

91.

  (a) Quando si sta per tirare, lo Striker deve toccare entrambe le
      Linee di Base.

  (b) Se il tiro viene effettuato a partire da uno dei Cerchi di Base,
      lo Striker lo deve coprire completamente ma non deve toccare le
      frecce diagonali.

92. Nei Doppi, durante la partita non è consentito ai partner di
    parlare o comunicare anche a gesti. Qualunque violazione di questa
    regola è trattata come un Fallo, e punita secondo le Regole

93. Ai giocatori non è permesso di parlare con gli spettatori senza il
    permesso dell'Arbitro.

94. Durante il loro turno di gioco, i giocatori non possono tenere in
    mano nessun materiale solido, eccetto lo Striker.

95. Le pedine e la Regina non devono essere mosse o disturbate, dopo
    la spaccata, se non con un tiro. Se vengono toccate, spostate o
    disturbate dopo la spaccata, la loro posizione originale deve
    essere per quanto possibile ripristinata dall'Arbitro, che
    dichiarerà fallo nei confronti del giocatore che ha commesso il
    fatto.

96. Non è permesso fare delle prove sul Tavolo con lo Striker durante
    il corso della partita.

97.

  (a) Durante la partita, i giocatori non devono tenere i loro Striker
      sul bordo del Tavolo, o in una delle buche.

  (b) Tuttavia al giocatore che deve posizionare la penalità è
      consentito, mentre effettua l'operazione, di appoggiare lo
      Striker sul bordo, esclusivamente sulla sponda vicina alle
      proprie Linee di Base.

98. Se i giocatori si passano la mano per tre volte consecutive
    ognuno, la partita viene annullata e deve essere rigiocata.

99. Deve esserci un intervallo di dieci minuti tra il secondo e il
    terzo game.

100. È consentito a ogni giocatore di concedere l'incontro o la partita
     in qualunque momento.

101. Se, per motivi imprevisti fuori dal controllo dell'Arbritro fosse
     impossibile ripristinare la posizione delle pedine sul Tavolo,
     quella particolare partita andrà rigiocata.

102. Se si dovesse rompere una pedina durante una partita, farà fede la
     posizione del pezzo più grande, e l'Arbitro avrà la parola
     definitiva.

103. Nell'eventualità che sia le Linee di Base che i Cerchi di Base
     risultassero occupati dalle pedine in modo tale da rendere
     impossibile a un giocatore il posizionamento dello Striker per
     tirare, il board dovrà essere rigiocato.

Perdita dell'incontro
=====================

104. Quando un giocatore commette uno qualsiasi di questi atti di
     indisciplina viene dichiarato perdente dell'intero incontro
     dall'Arbitro:

     (a) Lascia il proprio posto senza il permesso dell'Arbitro.

     (b) Non rispetta il limite di tempo per il riposo previsto prima
         della partita decisiva di un incontro.

     (c) Non rispetta le decisioni dell'Arbitro o della Giuria.

     (d) Insulta l'arbitro prima, durante o immediatamente dopo
         l'incontro.

     (e) Fuma durante l'incontro, o gioca sotto l'influenza di bevande o
         droghe intossicanti.

     (f) Gioca con uno striker non certificato.

     (g) Smette di giocare durante l'incontro senza il permesso
         dell'Arbitro.

     (h) Disturba o distrae l'attenzione dell'avversario più di due volte
         durante il turno dell'avversario stesso, ignorando i richiami
         dell'Arbitro.

     (i) Non si presenta all'Arbitro entro 15 minuti da quando è stato
         annunciato l'incontro.

Proteste
========

105. Qualsiasi protesta deve essere presentata, scritta in Inglese e
     firmata dal giocatore o dal Capitano della squadra, alla Segreteria
     del Torneo, per tramite dell'Arbitro.

106. Le proteste orali dovranno essere immediatamente rese note
     all'Arbitro, insieme al pagamento della tassa prevista. Nessuna
     protesta sarà accettata senza il pagamento della tassa.

107. Le proteste scritte devono essere presentate entro 15 minuti dalla
     conclusione della partita in questione.

108. La protesta dovrà descrivere la situazione occorsa, la decisione
     presa dall'Arbitro e l'obbiezione sollevata dalla parte in causa.

109. Le proteste formulate con un linguaggio volgare e inappropriato
     saranno rigettate e daranno seguito a azioni disciplinari.

110. Una volta che la protesta è stata presentata, non è permesso
     ritirarla.

111. Dopo che la protesta è stata presentata e accolta, il gioco dovrà
     continuare da dove era stato sospeso. Il risultato dell'incontro
     non sarà annunciato finché la Giuria non emette il verdetto sulla
     protesta.

112. Il verdetto della Giuria deve essere comunicato alle parti in causa
     entro un'ora da quando è stata presentata la protesta.

     (a) Se il verdetto è a favore, l'incontro dovrà continuare
         rigiocando dall'inizio la partita che si stava effettuando
         quando è stata presentata la protesta e la tassa verrà
         restituita.

     (b) Se invece la Giuria non accetta la protesta, il risultato
         dell'incontro rimane immutato e la tassa viene trattenuta.
